@@ -1,16 +1,13 @@
-import sys
-
 from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 from ploomber.util.default import extract_name
-import datetime
 
 from ploomber.telemetry import telemetry
 
 
 @cli_endpoint
+@telemetry.log_call('plot')
 def main():
-    start_time = datetime.datetime.now()
     parser = CustomParser(description='Plot a pipeline', prog='ploomber plot')
     with parser:
         parser.add_argument(
@@ -27,9 +24,5 @@ def main():
         output = 'pipeline.png' if name is None else f'pipeline.{name}.png'
 
     dag.plot(output=output)
-    end_time = datetime.datetime.now()
-    telemetry.log_api("ploomber_plot",
-                      total_runtime=str(end_time - start_time),
-                      dag=dag,
-                      metadata={'argv': sys.argv})
+
     print('Plot saved at:', output)
